#
# spec file for package ghc-case-insensitive
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name case-insensitive
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.2.1.0
Release:        6.18
Summary:        Case insensitive string comparison
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-hunit-prof
BuildRequires:  ghc-test-framework-prof
%endif

%description
The module 'Data.CaseInsensitive' provides the 'CI' type constructor which can
be parameterised by a string-like type like: 'String', 'ByteString', 'Text',
etc.. Comparisons of values of the resulting type will be insensitive to cases.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG README.markdown

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Mon May  6 2019 psimons@suse.com
- Update case-insensitive to version 1.2.1.0.
  1.2.1.0
  * Add traverse
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update case-insensitive to version 1.2.0.11.
  * Dropped upper version bounds of dependencies because it's to
    much work to maintain.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed May 31 2017 psimons@suse.com
- Update to version 1.2.0.10.
* Mon Apr 24 2017 psimons@suse.com
- Update to version 1.2.0.9 with cabal2obs.
* Mon Feb 20 2017 psimons@suse.com
- Update to version 1.2.0.8 with cabal2obs.
* Mon Jul 25 2016 psimons@suse.com
- Update to version 1.2.0.7 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.2.0.6 revision 0 with cabal2obs.
* Wed Mar 16 2016 mimi.vx@gmail.com
- update to 1.2.0.6
  * Add Semigroup s => Semigroup (CI s) instance
* Sun Oct  4 2015 mimi.vx@gmail.com
- update to 1.2.0.5
  * Support HUnit-1.3
  * Support criterion-1.1
* Mon Apr 13 2015 mimi.vx@gmail.com
- update to 1.2.0.4
  * Fixed #17: https://github.com/basvandijk/case-insensitive/issues/17
  * Bump base and deepseq upper bounds for GHC 7.10 compatibility
  * Add case-insensitive.nix and default.nix
  * Fix #14: Build failure with GHC 7.2.2
  * Fix #8: Don't unnecessarily use NoImplicitPrelude
  * Solved warnings on GHC-7.8.3
  * Bump text upper version bounds
  * Derived a Data instance for CI
* Tue Sep  9 2014 peter.trommler@ohm-hochschule.de
- update to 1.1.0.3
  * no changelog
  * for Haskell Platform 2014.2.0.0
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Tue May  7 2013 peter.trommler@ohm-hochschule.de
- update to 1.0.0.1 from upstream
  * modifications requested for Haskell Platform
  * support for hashable 1.2
  * improved performance for byte strings
- part of Haskell Platform 2013.2
- more transparent packaging (fewer macros)
* Sat Jun  9 2012 peter.trommler@ohm-hochschule.de
- packaged LICENSE file
- added copyright notice
- dropped rpmlintrc
* Fri Mar 30 2012 peter.trommler@ohm-hochschule.de
- Fixed typo in BR.
* Fri Mar 30 2012 peter.trommler@ohm-hochschule.de
- Initial packaging.
